--- meta: title: Elevation description: Elevation tokens are used to give elements the appearance of being raised off the page. --- # Elevation Tokens Elevation tokens are used to give elements the appearance of being raised off the page. Use them with the `box-shadow` property. These are especially useful for menus, popovers, and dialogs. | Token | Example | | ------------------------ | ----------------------------------------------------------------------------------- | | `--terra-shadow-x-small` |
| | `--terra-shadow-small` |
| | `--terra-shadow-medium` |
| | `--terra-shadow-large` |
| | `--terra-shadow-x-large` |
|